BinarySearchInGpcEfficient<P extends GpsPoint, F> class
- Inheritance
-
- Object
- SearchAlgorithm<
P, GpcEfficient< P> , F> - BinarySearch<
P, GpcEfficient< P> , F> - BinarySearchInGpcEfficient
Constructors
-
BinarySearchInGpcEfficient(GpcEfficient<
P> collection, SearchCompareDiff<GpcEfficient< compareDiff)P> , F>
Properties
-
collection
→ GpcEfficient<
P> -
The collection on which the search will be performed.
finalinherited
-
compareDiff
→ SearchCompareDiff<
GpcEfficient< P> , F> -
The comparison function that will be used to identify the desired item.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
find(
F target, [num? tolerance, int start = 0, int? end]) → int? -
Tries to find and return the item index between
startandendfor which the compareDiff returns TimeComparisonResult.same or TimeComparisonResult.overlapping, or that is withintolerancefromtarget. If such an item is not fount, the function null.inherited -
findUnsafe(
F target, num? tolerance, int start, int end) → int? -
Internal implementation for find, which does not do any validity checks
on its arguments. Not to be called directly.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited